// ***********************************************************************************************************************************************************
//
// nockieboy_ALU.sv
//
// My first ALU, complete with crayon marks, excessive glue and fingerprints.
//
// Version 0.1, 8th September 2022
//
// Written by Brian Guralnick and Jonathan Nock.
//
// Leave questions related to the project in https://www.eevblog.com/forum/fpga/fpga-vga-controller-for-8-bit-computer/
//
// ***********************************************************************************************************************************************************

module nockieboy_ALU (

    input  logic        clk,    // clk
    input  logic        areset, // reset
    input  logic        en,     // en
    input  logic [31:0] a,      // a
    input  logic [31:0] b,      // b
    output logic [31:0] q       // q

);

  parameter bit [7:0] FPU_A      = 'hE0 ; // IO address for FPU interface - Input  A, low-byte of 32-bit input.
  parameter bit [7:0] FPU_B      = 'hE4 ; // IO address for FPU interface - Input  B, low-byte of 32-bit input.
  parameter bit [7:0] FPU_Q      = 'hE8 ; // IO address for FPU interface - Output Q, low-byte of 32-bit output.
                                          // FPU_Q ends with 'hEB.

  logic [31:0] factor_A ;
  logic [31:0] factor_B ;
  logic [31:0] output_Q ;

  always_ff @(posedge clk) begin

    if (en) begin
      factor_A <= a ;
      factor_B <= b ;
      q <= output_Q ;
    end

  end

  FP_MULT multiplier (

    .clk    ( clk      ), // clk
    .areset ( areset   ), // reset
    .en     ( 1'b1     ), // en
    .a      ( factor_A ), // a
    .b      ( factor_B ), // b
    .q      ( output_Q )  // output

  );

endmodule
